@@ -1,6 +1,6 @@
 Puppet::Type.type(:neutron_api_paste_ini).provide(
   :ini_setting,
-  :parent => Puppet::Type.type(:ini_setting).provider(:ruby)
+  :parent => Puppet::Type.type(:openstack_config).provider(:ini_setting)
 ) do
 
   def section
@@ -19,9 +19,4 @@ Puppet::Type.type(:neutron_api_paste_ini).provide(
     '/etc/neutron/api-paste.ini'
   end
 
-  # added for backwards compatibility with older versions of inifile
-  def file_path
-    self.class.file_path
-  end
-
 end
