@@ -6,19 +6,16 @@ describe 'neutron::agents::ml2::ovs' do
   end
 
   let :default_params do
-    { :package_ensure             => 'present',
-      :enabled                    => true,
-      :bridge_uplinks             => [],
-      :bridge_mappings            => [],
-      :integration_bridge         => 'br-int',
-      :local_ip                   => false,
-      :tunnel_types               => [],
-      :tunnel_bridge              => 'br-tun',
-      :drop_flows_on_start        => false,
-      :firewall_driver            => 'iptables_hybrid',
-      :manage_vswitch             => true,
-      :purge_config               => false,
-      :enable_dpdk                => false,
+    { :package_ensure  => 'present',
+      :enabled         => true,
+      :bridge_uplinks  => [],
+      :bridge_mappings => [],
+      :local_ip        => false,
+      :tunnel_types    => [],
+      :firewall_driver => 'iptables_hybrid',
+      :manage_vswitch  => true,
+      :purge_config    => false,
+      :enable_dpdk     => false,
       }
   end
 
@@ -45,7 +42,7 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('DEFAULT/rpc_response_max_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/l2_population').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/arp_responder').with_value('<SERVICE DEFAULT>')
-      should contain_neutron_agent_ovs('agent/drop_flows_on_start').with_value(p[:drop_flows_on_start])
+      should contain_neutron_agent_ovs('agent/drop_flows_on_start').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/extensions').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/minimize_polling').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/tunnel_csum').with_value('<SERVICE DEFAULT>')
@@ -55,17 +52,19 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('ovs/of_connect_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_request_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_inactivity_probe').with_value('<SERVICE DEFAULT>')
-      should contain_neutron_agent_ovs('ovs/integration_bridge').with_value(p[:integration_bridge])
+      should contain_neutron_agent_ovs('ovs/integration_bridge').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('securitygroup/firewall_driver').\
         with_value(p[:firewall_driver])
       should contain_neutron_agent_ovs('securitygroup/enable_security_group').\
         with_value('<SERVICE DEFAULT>')
-      should_not contain_neutron_agent_ovs('securitygroup/permitted_ethertypes')
+      should contain_neutron_agent_ovs('securitygroup/permitted_ethertypes').\
+        with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/tunnel_bridge').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/local_ip').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/int_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/tun_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('agent/tunnel_types').with_ensure('absent')
+      should contain_neutron_agent_ovs('agent/vxlan_udp_port').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/bridge_mac_table_size').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
@@ -89,14 +88,11 @@ describe 'neutron::agents::ml2::ovs' do
     end
 
     it 'installs neutron ovs agent package' do
-      if platform_params.has_key?(:ovs_agent_package)
-        should contain_package('neutron-ovs-agent').with(
-          :name   => platform_params[:ovs_agent_package],
-          :ensure => p[:package_ensure],
-          :tag    => ['openstack', 'neutron-package'],
-        )
-      else
-      end
+      should contain_package('neutron-ovs-agent').with(
+        :name   => platform_params[:ovs_agent_package],
+        :ensure => p[:package_ensure],
+        :tag    => ['openstack', 'neutron-package'],
+      )
     end
 
     it 'configures neutron ovs agent service' do
@@ -119,7 +115,7 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
-    context 'when supplying permitted ethertypes' do
+    context 'when supplying permitted ethertypes by an array' do
       before :each do
         params.merge!(:permitted_ethertypes => ['0x4008', '0x5'])
       end
@@ -128,6 +124,15 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
+    context 'when supplying permitted ethertypes by a string' do
+      before :each do
+        params.merge!(:permitted_ethertypes => '0x4008,0x5')
+      end
+      it 'should configured ethertypes' do
+        should contain_neutron_agent_ovs('securitygroup/permitted_ethertypes').with_value('0x4008,0x5')
+      end
+    end
+
     context 'when supplying a firewall driver' do
       before :each do
         params.merge!(:firewall_driver => false)
@@ -277,28 +282,37 @@ describe 'neutron::agents::ml2::ovs' do
     context 'when enabling tunneling' do
       context 'without local ip address' do
         before :each do
-          params.merge!(:tunnel_types => ['vxlan'])
+          params.merge!({
+            :tunnel_types => ['vxlan']
+          })
         end
 
         it { should raise_error(Puppet::Error, /Local ip for ovs agent must be set when tunneling is enabled/) }
       end
+
       context 'with default params' do
         before :each do
-          params.merge!(:tunnel_types => ['vxlan'], :local_ip => '127.0.0.1' )
+          params.merge!({
+            :tunnel_types => ['vxlan'],
+            :local_ip     => '127.0.0.1'
+          })
         end
         it 'should configure ovs for tunneling' do
-          should contain_neutron_agent_ovs('ovs/tunnel_bridge').with_value(default_params[:tunnel_bridge])
+          should contain_neutron_agent_ovs('ovs/tunnel_bridge').with_value('<SERVICE DEFAULT>')
           should contain_neutron_agent_ovs('ovs/local_ip').with_value('127.0.0.1')
           should contain_neutron_agent_ovs('ovs/int_peer_patch_port').with_value('<SERVICE DEFAULT>')
           should contain_neutron_agent_ovs('ovs/tun_peer_patch_port').with_value('<SERVICE DEFAULT>')
+          should contain_neutron_agent_ovs('agent/vxlan_udp_port').with_value('<SERVICE DEFAULT>')
         end
       end
 
       context 'with vxlan tunneling' do
         before :each do
-          params.merge!(:local_ip => '127.0.0.1',
-                        :tunnel_types => ['vxlan'],
-                        :vxlan_udp_port => '4789')
+          params.merge!({
+            :tunnel_types   => ['vxlan'],
+            :local_ip       => '127.0.0.1',
+            :vxlan_udp_port => 49155
+          })
         end
 
         it 'should perform vxlan network configuration' do
@@ -309,10 +323,12 @@ describe 'neutron::agents::ml2::ovs' do
 
       context 'when l2 population is disabled and DVR and tunneling enabled' do
         before :each do
-          params.merge!(:enable_distributed_routing => true,
-                        :l2_population              => false,
-                        :tunnel_types               => ['vxlan'],
-                        :local_ip                   => '127.0.0.1' )
+          params.merge!({
+            :enable_distributed_routing => true,
+            :l2_population              => false,
+            :tunnel_types               => ['vxlan'],
+            :local_ip                   => '127.0.0.1'
+          })
         end
 
         it { should raise_error(Puppet::Error, /L2 population must be enabled when DVR and tunneling are enabled/) }
@@ -320,9 +336,11 @@ describe 'neutron::agents::ml2::ovs' do
 
       context 'when DVR is enabled and l2 population and tunneling are disabled' do
         before :each do
-          params.merge!(:enable_distributed_routing => true,
-                        :l2_population              => false,
-                        :tunnel_types               => [] )
+          params.merge!({
+            :enable_distributed_routing => true,
+            :l2_population              => false,
+            :tunnel_types               => []
+          })
         end
 
         it 'should enable DVR without L2 population' do
@@ -404,18 +422,20 @@ describe 'neutron::agents::ml2::ovs' do
     it 'configures neutron ovs cleanup service' do
       should contain_service('ovs-cleanup-service').with(
         :name    => platform_params[:ovs_cleanup_service],
-        :enable  => true
-      ).that_requires('Anchor[neutron::install::end]')
-      should contain_package('neutron-ovs-agent').that_requires('Anchor[neutron::install::begin]')
-      should contain_package('neutron-ovs-agent').that_notifies('Anchor[neutron::install::end]')
+        :enable  => true,
+        :ensure  => nil,
+        :require => 'Anchor[neutron::service::begin]',
+        :before  => 'Anchor[neutron::service::end]',
+      )
     end
 
     it 'configures neutron destroy patch ports service' do
       should contain_service('neutron-destroy-patch-ports-service').with(
-        :name   => platform_params[:destroy_patch_ports_service],
-        :enable => true,
-        :ensure => 'running',
-        :tag    => ['neutron-service'],
+        :name    => platform_params[:destroy_patch_ports_service],
+        :enable  => true,
+        :ensure  => nil,
+        :require => 'Anchor[neutron::service::begin]',
+        :before  => 'Anchor[neutron::service::end]',
       )
     end
 
@@ -480,7 +500,8 @@ describe 'neutron::agents::ml2::ovs' do
           { :ovs_agent_package => 'neutron-openvswitch-agent',
             :ovs_agent_service => 'neutron-openvswitch-agent' }
         when 'RedHat'
-          { :ovs_cleanup_service         => 'neutron-ovs-cleanup',
+          { :ovs_agent_package           => 'openstack-neutron-openvswitch',
+            :ovs_cleanup_service         => 'neutron-ovs-cleanup',
             :ovs_agent_service           => 'neutron-openvswitch-agent',
             :destroy_patch_ports_service => 'neutron-destroy-patch-ports' }
         end
