@@ -56,19 +56,21 @@ describe 'neutron::config' do
 
   shared_examples 'neutron_agent_config' do
     let :params do
-      { :ovs_agent_config      => config_hash,
-        :sriov_agent_config    => config_hash,
-        :l3_agent_config       => config_hash,
-        :dhcp_agent_config     => config_hash,
-        :metadata_agent_config => config_hash,
-        :metering_agent_config => config_hash,
-        :vpnaas_agent_config   => config_hash,
-        :l2gw_agent_config     => config_hash,
-        :bgp_dragent_config    => config_hash,
+      { :ovs_agent_config         => config_hash,
+        :sriov_agent_config       => config_hash,
+        :linuxbridge_agent_config => config_hash,
+        :macvtap_agent_config     => config_hash,
+        :l3_agent_config          => config_hash,
+        :dhcp_agent_config        => config_hash,
+        :metadata_agent_config    => config_hash,
+        :metering_agent_config    => config_hash,
+        :vpnaas_agent_config      => config_hash,
+        :l2gw_agent_config        => config_hash,
+        :bgp_dragent_config       => config_hash,
       }
     end
 
-    it 'configures arbitrary neutron_ovs_agent_config configurations' do
+    it 'configures arbitrary neutron_agent_ovs configurations' do
       should contain_neutron_agent_ovs('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_agent_ovs('DEFAULT/bar').with_value('barValue')
       should contain_neutron_agent_ovs('DEFAULT/baz').with_ensure('absent')
@@ -80,6 +82,18 @@ describe 'neutron::config' do
       should contain_neutron_sriov_agent_config('DEFAULT/baz').with_ensure('absent')
     end
 
+    it 'configures arbitrary neutron_agent_linuxbridge configurations' do
+      should contain_neutron_agent_linuxbridge('DEFAULT/foo').with_value('fooValue')
+      should contain_neutron_agent_linuxbridge('DEFAULT/bar').with_value('barValue')
+      should contain_neutron_agent_linuxbridge('DEFAULT/baz').with_ensure('absent')
+    end
+
+    it 'configures arbitrary neutron_agent_macvtap configurations' do
+      should contain_neutron_agent_macvtap('DEFAULT/foo').with_value('fooValue')
+      should contain_neutron_agent_macvtap('DEFAULT/bar').with_value('barValue')
+      should contain_neutron_agent_macvtap('DEFAULT/baz').with_ensure('absent')
+    end
+
     it 'configures arbitrary l3_agent_config configurations' do
       should contain_neutron_l3_agent_config('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_l3_agent_config('DEFAULT/bar').with_value('barValue')
@@ -127,33 +141,19 @@ describe 'neutron::config' do
   shared_examples 'neutron_plugin_config' do
     let :params do
       {
-        :plugin_linuxbridge_config     => config_hash,
         :plugin_nsx_config             => config_hash,
-        :plugin_nvp_config             => config_hash,
         :plugin_opencontrail_config    => config_hash,
         :plugin_nuage_config           => config_hash,
         :plugin_ml2_config             => config_hash
       }
     end
 
-    it 'configures arbitrary neutron_plugin_linuxbridge configurations' do
-      should contain_neutron_plugin_linuxbridge('DEFAULT/foo').with_value('fooValue')
-      should contain_neutron_plugin_linuxbridge('DEFAULT/bar').with_value('barValue')
-      should contain_neutron_plugin_linuxbridge('DEFAULT/baz').with_ensure('absent')
-    end
-
     it 'configures arbitrary neutron_plugin_nsx configurations' do
       should contain_neutron_plugin_nsx('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_plugin_nsx('DEFAULT/bar').with_value('barValue')
       should contain_neutron_plugin_nsx('DEFAULT/baz').with_ensure('absent')
     end
 
-    it 'configures arbitrary neutron_plugin_nvp configurations' do
-      should contain_neutron_plugin_nvp('DEFAULT/foo').with_value('fooValue')
-      should contain_neutron_plugin_nvp('DEFAULT/bar').with_value('barValue')
-      should contain_neutron_plugin_nvp('DEFAULT/baz').with_ensure('absent')
-    end
-
     it 'configures arbitrary neutron_plugin_opencontrail configurations' do
       should contain_neutron_plugin_opencontrail('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_plugin_opencontrail('DEFAULT/bar').with_value('barValue')
