@@ -11,26 +11,16 @@ describe 'neutron::plugins::ml2::mellanox' do
      }"
   end
 
-  let :default_params do
-    {
-      :package_ensure => 'present'
-    }
-  end
-
   let :params do
     {}
   end
 
   shared_examples 'neutron plugin mellanox ml2' do
-    before do
-      params.merge!(default_params)
-    end
-
     it { should contain_class('neutron::params') }
 
     it 'should have' do
-      should contain_package('python-networking-mlnx').with(
-        :ensure => params[:package_ensure],
+      should contain_package(platform_params[:mlnx_plugin_package]).with(
+        :ensure => 'installed',
         :tag    => ['openstack', 'neutron-plugin-ml2-package']
         )
     end
@@ -44,9 +34,20 @@ describe 'neutron::plugins::ml2::mellanox' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      if facts[:osfamily] == 'RedHat'
-        it_behaves_like 'neutron plugin mellanox ml2'
+      let (:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          {
+            :mlnx_plugin_package => 'python3-networking-mlnx',
+          }
+        when 'RedHat'
+          {
+            :mlnx_plugin_package => 'python3-networking-mlnx',
+          }
+        end
       end
+
+      it_behaves_like 'neutron plugin mellanox ml2'
     end
   end
 end
