@@ -31,7 +31,7 @@ describe 'neutron::plugins::ml2' do
     {
       :type_drivers          => ['local', 'flat', 'vlan', 'gre', 'vxlan', 'geneve'],
       :tenant_network_types  => ['local', 'flat', 'vlan', 'gre', 'vxlan'],
-      :mechanism_drivers     => ['openvswitch', 'linuxbridge'],
+      :mechanism_drivers     => ['openvswitch'],
       :flat_networks         => '*',
       :network_vlan_ranges   => '10:50',
       :tunnel_id_ranges      => '20:100',
@@ -276,17 +276,38 @@ describe 'neutron::plugins::ml2' do
         end
       end
     end
+  end
 
+  shared_examples 'neutron plugin ml2 on Debian' do
     context 'on Ubuntu operating systems' do
-      before do
-        facts.merge!({:operatingsystem => 'Ubuntu'})
-      end
-
       it 'configures /etc/default/neutron-server' do
+        should contain_file('/etc/default/neutron-server').with(
+          :ensure => 'present',
+          :owner  => 'root',
+          :group  => 'root',
+          :mode   => '0644',
+          :tag    => 'neutron-config-file',
+        )
+        should_not contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG')
+      end
+    end
+  end
+
+  shared_examples 'neutron plugin ml2 on Ubuntu' do
+    context 'on Ubuntu operating systems' do
+      it 'configures /etc/default/neutron-server' do
+        should contain_file('/etc/default/neutron-server').with(
+          :ensure => 'present',
+          :owner  => 'root',
+          :group  => 'root',
+          :mode   => '0644',
+          :tag    => 'neutron-config-file',
+        )
         should contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG').with(
           :path    => '/etc/default/neutron-server',
           :match   => '^NEUTRON_PLUGIN_CONFIG=(.*)$',
           :line    => 'NEUTRON_PLUGIN_CONFIG=/etc/neutron/plugin.ini',
+          :tag     => 'neutron-file-line',
         )
         should contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG').that_requires('Anchor[neutron::config::begin]')
         should contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG').that_notifies('Anchor[neutron::config::end]')
@@ -294,6 +315,15 @@ describe 'neutron::plugins::ml2' do
     end
   end
 
+  shared_examples 'neutron plugin ml2 on RedHat' do
+    context 'on Ubuntu operating systems' do
+      it 'should not configure /etc/default/neutron-server' do
+        should_not contain_file('/etc/default/neutron-server')
+        should_not contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG')
+      end
+    end
+  end
+
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -320,6 +350,12 @@ describe 'neutron::plugins::ml2' do
       end
 
       it_behaves_like 'neutron plugin ml2'
+
+      if facts[:osfamily] == 'Debian'
+        it_behaves_like "neutron plugin ml2 on #{facts[:operatingsystem]}"
+      else
+        it_behaves_like "neutron plugin ml2 on #{facts[:osfamily]}"
+      end
     end
   end
 end
