@@ -4,15 +4,13 @@ describe 'neutron::wsgi::apache' do
   shared_examples 'apache serving neutron with mod_wsgi' do
     context 'with default parameters' do
       it { should contain_class('neutron::params') }
-      it { should contain_class('apache') }
-      it { should contain_class('apache::mod::wsgi') }
-      it { should contain_class('apache::mod::ssl') }
       it { should contain_openstacklib__wsgi__apache('neutron_wsgi').with(
         :bind_port                   => 9696,
         :group                       => 'neutron',
         :path                        => '/',
+        :priority                    => 10,
         :servername                  => facts[:fqdn],
-        :ssl                         => true,
+        :ssl                         => false,
         :threads                     => 1,
         :user                        => 'neutron',
         :workers                     => facts[:os_workers],
@@ -22,39 +20,42 @@ describe 'neutron::wsgi::apache' do
         :wsgi_script_file            => 'app',
         :wsgi_script_source          => platform_params[:wsgi_script_source],
         :custom_wsgi_process_options => {},
-        :access_log_file             => false,
-        :access_log_format           => false,
+        :headers                     => nil,
+        :request_headers             => nil,
+        :access_log_file             => nil,
+        :access_log_pipe             => nil,
+        :access_log_syslog           => nil,
+        :access_log_format           => nil,
+        :error_log_file              => nil,
+        :error_log_pipe              => nil,
+        :error_log_syslog            => nil,
       )}
     end
 
-    context 'when overriding parameters using different ports' do
+    context 'when overriding parameters' do
       let :params do
         {
           :servername                => 'dummy.host',
           :bind_host                 => '10.42.51.1',
           :port                      => 12345,
-          :ssl                       => false,
+          :ssl                       => true,
           :wsgi_process_display_name => 'neutron',
           :workers                   => 37,
           :custom_wsgi_process_options => {
             'python_path' => '/my/python/path',
           },
-          :access_log_file           => '/var/log/httpd/access_log',
-          :access_log_format         => 'some format',
-          :error_log_file            => '/var/log/httpd/error_log'
+          :headers                   => ['set X-XSS-Protection "1; mode=block"'],
+          :request_headers           => ['set Content-Type "application/json"'],
         }
       end
       it { should contain_class('neutron::params') }
-      it { should contain_class('apache') }
-      it { should contain_class('apache::mod::wsgi') }
-      it { should_not contain_class('apache::mod::ssl') }
       it { should contain_openstacklib__wsgi__apache('neutron_wsgi').with(
         :bind_host                   => '10.42.51.1',
         :bind_port                   => 12345,
         :group                       => 'neutron',
         :path                        => '/',
         :servername                  => 'dummy.host',
-        :ssl                         => false,
+        :ssl                         => true,
         :threads                     => 1,
         :user                        => 'neutron',
         :workers                     => 37,
@@ -64,12 +65,75 @@ describe 'neutron::wsgi::apache' do
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
         :wsgi_script_file            => 'app',
         :wsgi_script_source          => platform_params[:wsgi_script_source],
+        :headers                     => ['set X-XSS-Protection "1; mode=block"'],
+        :request_headers             => ['set Content-Type "application/json"'],
         :custom_wsgi_process_options => {
           'python_path' => '/my/python/path',
         },
-        :access_log_file             => '/var/log/httpd/access_log',
-        :access_log_format           => 'some format',
-        :error_log_file              => '/var/log/httpd/error_log'
+      )}
+    end
+
+    context 'with custom access logging' do
+      let :params do
+        {
+          :access_log_format => 'foo',
+          :access_log_syslog => 'syslog:local0',
+          :error_log_syslog  => 'syslog:local1',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('neutron_wsgi').with(
+        :access_log_format => params[:access_log_format],
+        :access_log_syslog => params[:access_log_syslog],
+        :error_log_syslog  => params[:error_log_syslog],
+      )}
+    end
+
+    context 'with access_log_file' do
+      let :params do
+        {
+          :access_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('neutron_wsgi').with(
+        :access_log_file => params[:access_log_file],
+      )}
+    end
+
+    context 'with access_log_pipe' do
+      let :params do
+        {
+          :access_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('neutron_wsgi').with(
+        :access_log_pipe => params[:access_log_pipe],
+      )}
+    end
+
+    context 'with error_log_file' do
+      let :params do
+        {
+          :error_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('neutron_wsgi').with(
+        :error_log_file => params[:error_log_file],
+      )}
+    end
+
+    context 'with error_log_pipe' do
+      let :params do
+        {
+          :error_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('neutron_wsgi').with(
+        :error_log_pipe => params[:error_log_pipe],
       )}
     end
   end
@@ -90,15 +154,11 @@ describe 'neutron::wsgi::apache' do
         case facts[:osfamily]
         when 'Debian'
           {
-            :httpd_service_name => 'apache2',
-            :httpd_ports_file   => '/etc/apache2/ports.conf',
             :wsgi_script_path   => '/usr/lib/cgi-bin/neutron',
             :wsgi_script_source => '/usr/bin/neutron-api'
           }
         when 'RedHat'
           {
-            :httpd_service_name => 'httpd',
-            :httpd_ports_file   => '/etc/httpd/conf/ports.conf',
             :wsgi_script_path   => '/var/www/cgi-bin/neutron',
             :wsgi_script_source => '/usr/bin/neutron-api'
           }
